pub fn is_better_payload<T: BuiltPayload>(
best_payload: Option<&T>,
new_fees: U256,
) -> boolExpand description
Checks if the new payload is better than the current best.
This compares the total fees of the blocks, higher is better.
pub fn is_better_payload<T: BuiltPayload>(
best_payload: Option<&T>,
new_fees: U256,
) -> boolChecks if the new payload is better than the current best.
This compares the total fees of the blocks, higher is better.