pub struct BuildArguments<Attributes, Payload: BuiltPayload> {
pub cached_reads: CachedReads,
pub execution_cache: Option<SavedCache>,
pub trie_handle: Option<StateRootHandle>,
pub config: PayloadConfig<Attributes, HeaderTy<Payload::Primitives>>,
pub cancel: CancelOnDrop,
pub best_payload: Option<Payload>,
}Expand description
A collection of arguments used for building payloads.
This struct encapsulates the essential components and configuration required for the payload building process. It holds references to the Ethereum client, transaction pool, cached reads, payload configuration, cancellation status, and the best payload achieved so far.
Fields
cached_reads: CachedReadsPreviously cached disk reads
execution_cache: Option<SavedCache>Optional execution cache shared with the engine.
trie_handle: Option<StateRootHandle>Optional state root task handle, shared with the engine.
The preserved trie is shared with the engine, so a concurrent newPayload will
block until this task completes. The trie is anchored at the built block’s state
root, so if the next newPayload is not on top of that block, the trie cache is
invalidated and cleared.
config: PayloadConfig<Attributes, HeaderTy<Payload::Primitives>>How to configure the payload.
cancel: CancelOnDropA marker that can be used to cancel the job.
best_payload: Option<Payload>The best payload achieved so far.
Implementations
Sourceimpl<Attributes, Payload: BuiltPayload> BuildArguments<Attributes, Payload>
impl<Attributes, Payload: BuiltPayload> BuildArguments<Attributes, Payload>
Sourcepub const fn new(
cached_reads: CachedReads,
execution_cache: Option<SavedCache>,
trie_handle: Option<StateRootHandle>,
config: PayloadConfig<Attributes, HeaderTy<Payload::Primitives>>,
cancel: CancelOnDrop,
best_payload: Option<Payload>,
) -> Self
pub const fn new( cached_reads: CachedReads, execution_cache: Option<SavedCache>, trie_handle: Option<StateRootHandle>, config: PayloadConfig<Attributes, HeaderTy<Payload::Primitives>>, cancel: CancelOnDrop, best_payload: Option<Payload>, ) -> Self
Create new build arguments.